KBGraphBuilder class

Constructors

KBGraphBuilder(KbStorage storage)
KBGraphBuilder.file(dynamic kbDir)
Creates a graph builder for the classic Markdown file backend.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storage → KbStorage
final

Methods

build({int maxMermaidNodes = 100}) → Future<void>
Regenerates GRAPH.md in the knowledge-base root.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited