KBQuestionAnswerMappingAgent class

Maps new answers and notes to existing unanswered questions.

Constructors

KBQuestionAnswerMappingAgent(LlmProvider _provider)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

mapAnswers(AnalysisResult newResult, KBContext context, {String extraInstructions = ''}) Future<QAMappingResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited