KBRerankerAgent class

Reranks a small set of candidate memory records for a given query using an LLM. This is useful when lexical/tag-based scoring is not enough to surface the most relevant record.

Constructors

KBRerankerAgent(LlmProvider _provider)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rerank(String query, List<MemoryRecord> candidates, {String extraInstructions = ''}) Future<List<String>>
Reranks candidates for query.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited