KBSearchResult class

Result of a knowledge-base search.

Constructors

KBSearchResult({required String path, required String entityType, Question? question, Answer? answer, Note? note, required List<String> matchedTags})
const

Properties

answer Answer?
final
entityType String
final
hashCode int
The hash code for this object.
no setterinherited
id String?
no setter
matchedTags List<String>
final
note Note?
final
path String
final
question Question?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
All tags of the underlying entity.
no setter
title String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
withMatchedTags(List<String> tags) KBSearchResult
Convenience helper for creating a copy with updated matched tags.

Operators

operator ==(Object other) bool
The equality operator.
inherited