LlmMessage class

A single message in a conversational LLM exchange.

images are base64 data URLs (e.g. data:image/png;base64,...) used by vision-capable models. They are serialized into OpenAI-compatible content blocks.

Constructors

LlmMessage({required String role, required String content, List<String>? images})
const

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
images List<String>?
final
role String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited