Question class

A knowledge-base question.

Constructors

Question({required String id, required String author, required String text, String? startTextRef, String? endTextRef, required String date, required String area, required List<String> topics, required List<String> tags, String? answeredBy, required List<Link> links, int accessCount = 0, String? lastAccessedAt, double importance = 0.5})
const
Question.fromJson(Map<String, dynamic> json)
factory

Properties

accessCount int
final
answeredBy String?
final
area String
final
author String
final
date String
final
endTextRef String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
importance double
final
lastAccessedAt String?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTextRef String?
final
tags List<String>
final
text String
final
topics List<String>
final

Methods

copyWith({String? id, String? author, String? text, String? startTextRef, String? endTextRef, String? date, String? area, List<String>? topics, List<String>? tags, String? answeredBy, List<Link>? links, int? accessCount, String? lastAccessedAt, double? importance}) Question
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBaseJson() Map<String, dynamic>
Serializes the fields common to all knowledge-base entities.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited