storage library

Public storage adapters for flutter_agent_memory.

Import this library when you need to plug in a custom backend, use the framework in a test sandbox, or run on web/SQLite.

Classes

FileKbStorage
File-system implementation of KbStorage.
HttpKbStorage
HTTP-backed implementation of KbStorage.
InMemoryKbStorage
In-memory implementation of KbStorage.
KbStorage
Abstract storage backend for the agent knowledge base.
SqliteKbStorage
SQLite implementation of KbStorage.
WebKbStorage
Browser-storage implementation of KbStorage.