KBAnalysisAgent class
Extracts structured knowledge (questions, answers, notes) from raw text and optionally images.
Constructors
- KBAnalysisAgent(LlmProvider _provider)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
analyze(
String inputText, KBContext context, {String sourceName = 'unknown', String extraInstructions = '', List< String> ? images, String template = 'kb_analysis.xml'}) → Future<AnalysisResult> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited