MemoryConsolidationWriter class

Writes the result of a consolidation run: the MEMORY.md summary and the derived skill cards.

Properties

hashCode int
The hash code for this object.
no setterinherited
revision MemoryRevisionService
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storage KbStorage
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(ConsolidationResult result, {String? expectedRevisionHash}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited