MemoryLevelService class
Promotes or expires notes according to a MemoryPromotionPolicy.
Constructors
-
MemoryLevelService({required KbStorage storage, required MemoryPromotionPolicy policy, required Future<
void> deleteRecord(String id), required Future<void> writeNote(Note note), required Future<List< listNotes()})Note> >
Properties
-
deleteRecord
→ Future<
void> Function(String id) -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
listNotes
→ Future<
List< Function()Note> > -
final
- policy → MemoryPromotionPolicy
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storage → KbStorage
-
final
-
writeNote
→ Future<
void> Function(Note note) -
final
Methods
-
maintain(
) → Future< int> - Promotes or expires notes according to policy and returns the number of records changed.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited