MemoryPromotionPolicy class
Policy controlling automatic promotion and expiry of memory levels.
Raw records that survive for rawToConsolidatedAfter without contradiction are promoted to consolidated. Consolidated records older than consolidatedToConceptAfter are promoted to concept. Raw records that are not confirmed within rawExpiryAfter can be removed.
Constructors
- MemoryPromotionPolicy({Duration rawToConsolidatedAfter = const Duration(days: 14), Duration consolidatedToConceptAfter = const Duration(days: 90), Duration rawExpiryAfter = const Duration(days: 30)})
-
const
Properties
- consolidatedToConceptAfter → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rawExpiryAfter → Duration
-
final
- rawToConsolidatedAfter → Duration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited