Note class
A standalone knowledge-base note.
Notes can optionally carry a memoryType (fact, event, observation, belief, etc.) so that durable memories do not get mixed with question/answer pairs. Optional validFrom / validUntil fields support temporal queries.
Constructors
-
Note({required String id, required String text, String? startTextRef, String? endTextRef, required String area, required List<
String> topics, required List<String> tags, required String author, required String date, required List<String> answersQuestions, required List<Link> links, int accessCount = 0, String? lastAccessedAt, double importance = 0.5, String? memoryType, String? validFrom, String? validUntil, int level = MemoryLevel.raw, List<Relation> relations = const []}) -
const
-
Note.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accessCount → int
-
final
-
answersQuestions
→ List<
String> -
final
- area → String
-
final
-
final
- date → String
-
final
- endTextRef → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- importance → double
-
final
- lastAccessedAt → String?
-
final
- level → int
-
final
-
links
→ List<
Link> -
final
- memoryType → String?
-
final
-
relations
→ List<
Relation> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTextRef → String?
-
final
-
final
- text → String
-
final
-
topics
→ List<
String> -
final
- validFrom → String?
-
final
- validUntil → String?
-
final
Methods
-
copyWith(
{String? id, String? text, String? startTextRef, String? endTextRef, String? area, List< String> ? topics, List<String> ? tags, String? author, String? date, List<String> ? answersQuestions, List<Link> ? links, int? accessCount, String? lastAccessedAt, double? importance, String? memoryType, String? validFrom, String? validUntil, int? level, List<Relation> ? relations}) → Note -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBaseJson(
) → Map< String, dynamic> -
Serializes the fields common to all knowledge-base entities.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited