MemoryLevel class

Hierarchical memory levels inspired by reference frameworks (MemPalace drawers/closets, Mastra observations/reflections, Hindsight mental models).

Levels are stored as integers so that comparisons and thresholds are easy. Higher levels are more compressed and abstract.

Constructors

MemoryLevel()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromName(String? value) int?
nameOf(int level) String
normalize(int? level) int

Constants

concept → const int
consolidated → const int
names → const Map<int, String>
raw → const int